#ifndef QT_FEATURES_Protobuf_src_protobuf_qtprotobuf_config_p_h_H
#define QT_FEATURES_Protobuf_src_protobuf_qtprotobuf_config_p_h_H

#define QT_FEATURE_qtprotobufgen 1

#define QT_FEATURE_protobuf_unsafe_registry -1


#endif // QT_FEATURES_Protobuf_src_protobuf_qtprotobuf_config_p_h_H
